#!/bin/perl
#############################################################
# CA Service Desk 
# =========================
# Copyright (C) 2011-2013
# =========================
# Description: 
# The program gathers webengine statistics from CA Service Desk 
# =========================
# Usage: perl sd.pl my/qualified/casd/homedir
#
# NOTE: Even for Windows users, please use "/" as separators.
# If there are spaces in the directory names, use the 8.3
# format by opening a command prompt and type 'dir /x' to
# see the truncated name.
# e.g. C:\Program Files becomes C:\Progra~1
# e.g. C:\Program Files (x86) becomes C:\Progra~2
#############################################################
use FindBin;
use lib ("$FindBin::Bin", "$FindBin::Bin/lib/perl", "$FindBin::Bin/../lib/perl");
use Wily::PrintMetric;

use strict;

# get CASD home directory from input
my $homeDir= shift @_;
# webstat command
my $webstatCommand='bin/pdm_webstat -d';
# get results
my @webstatResults=`$homeDir/$webstatCommand`;
#my @webstatResults = do { open my $fh, '<','.\info.txt'; <$fh>; }; #to test, comment lines 26,28,30 & uncomment 31
# subroutine to get local server name
sub getServer {
    my $serverName;
    if ($^O eq 'aix' || $^O eq 'solaris' || $^O eq 'linux') {
        $serverName=`uname -n`;
    } else {
        # must be a windows device; use env variable %COMPUTERNAME%
        $serverName=$ENV{'COMPUTERNAME'};
    }
    return $serverName;
}


#### begin parsing results ####
my $webEngine;
foreach my $isline (@webstatResults) {
    chomp $isline; # remove trailing new line
    # skip the '=' separator row
    if ($isline =~ /^\=+$/){ next; }
    elsif ($isline =~ /^Report.*/) {
        #TODO: parse the host name
        (undef,undef,$webEngine,undef) = split (/:/, $isline);
        # determine if is server is 'local'
        if ($webEngine eq 'local') {
            $webEngine = getServer;
        }
        # next line
        next;
    } elsif (defined($webEngine) && $isline =~ /^Cumulative.*/) {
        #TODO: parse server metrics
        my($metric, $value) = split(/=/,$isline,2);
        # remove leading and trailing spaces
        $metric =~ s/^\s+//; $metric =~ s/\s+$//;
        $value =~ s/^\s+//; $value =~ s/\s+$//;
        # print metrics
        Wily::PrintMetric::printMetric( type        => 'IntCounter',
                                        resource    => 'CAServiceDesk',
                                        subresource => $webEngine,
                                        name        => $metric,
                                        value       => int($value)
                                        );
        # next line
        next;
    } elsif (defined($webEngine) && $isline =~ /^Most.*/) {
        #TODO: parse server metrics
        my($metric, $value) = split(/=/,$isline,2);
        # remove leading and trailing spaces
        $metric =~ s/^\s+//; $metric =~ s/\s+$//;
        $value =~ s/^\s+//; $value =~ s/\s+$//;
        # print metrics
        Wily::PrintMetric::printMetric( type        => 'IntCounter',
                                        resource    => 'CAServiceDesk',
                                        subresource => $webEngine,
                                        name        => $metric,
                                        value       => int($value)
                                        );
        # next line
        next;
    } elsif (defined($webEngine) && $isline =~ /^Currently.*/) {
        #TODO: parse server metrics
        my($metric, $value) = split(/=/,$isline,2);
        # remove leading and trailing spaces
        $metric =~ s/^\s+//; $metric =~ s/\s+$//;
        $value =~ s/^\s+//; $value =~ s/\s+$//;
        # print metrics
        Wily::PrintMetric::printMetric( type        => 'IntCounter',
                                        resource    => 'CAServiceDesk',
                                        subresource => $webEngine,
                                        name        => $metric,
                                        value       => int($value)
                                        );
       # clear $webEngine
       undef $webEngine;
    }
}
